staging — Staging of input/output files on a queuing system — GromacsWrapper 0.5.0-dev documentation

# `staging` — Staging of input/output files on a queuing system

The `staging` module provides a framework to run python scripts easily through a queuing system that requires copying of files to the scratch directory on compute nodes (“staging”). Instead of submitting a shell script to the queuing system, one uses a python script that imports the module and instantiates a `Job` class that contains methods to manage staging.

- `staging` — Staging module overview
- `staging.SunGridEngine` — staging class for SunGridEngine
- `staging.Local` — staging class for running local jobs